==> jc-1.4.0.tar.gz: java/awt/event/TextEvent.h <==
// public class java.awt.event.TextEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class 724e5862254ff405 java_awt_event_TextEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_TextEvent_H_
#define _JC_java_awt_event_TextEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_TextEvent$sub_refs	_jc_java_awt_event_TextEvent$sub_refs;
typedef struct _jc_java_awt_event_TextEvent$sub_nonrefs	_jc_java_awt_event_TextEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_TextEvent$refs	_jc_java_awt_event_TextEvent$refs;
typedef struct _jc_java_awt_event_TextEvent$nonrefs	_jc_java_awt_event_TextEvent$nonrefs;
typedef struct _jc_java_awt_event_TextEvent$object	_jc_java_awt_event_TextEvent$object;

typedef struct _jc_java_awt_event_TextEvent$fields_struct	_jc_java_awt_event_TextEvent$fields_struct;
typedef const struct _jc_java_awt_event_TextEvent$vmethods	_jc_java_awt_event_TextEvent$vmethods;
typedef const struct _jc_java_awt_event_TextEvent$vtable	_jc_java_awt_event_TextEvent$vtable;
typedef const struct _jc_java_awt_event_TextEvent$vtype	_jc_java_awt_event_TextEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_TextEvent$fields_struct {
	jlong	serialVersionUID;
	jint	TEXT__5fFIRST;
	jint	TEXT__5fLAST;
	jint	TEXT__5fVALUE__5fCHANGED;
};
extern _jc_java_awt_event_TextEvent$fields_struct _jc_java_awt_event_TextEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_TextEvent$method$_init$a57db7ba48d4b8bc(_jc_env *, struct _jc_java_awt_event_TextEvent$object *, struct _jc_java_lang_Object$object *, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_awt_event_TextEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_TextEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_TextEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_TextEvent$vmethods {
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_TextEvent$object *);
};

// Vtable
struct _jc_java_awt_event_TextEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_TextEvent$vmethods	java_awt_event_TextEvent;
};

// Vtype
struct _jc_java_awt_event_TextEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_TextEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_TextEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_TextEvent$refs {
    _jc_java_awt_event_TextEvent$sub_refs	java_awt_event_TextEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_TextEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_TextEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_TextEvent$sub_nonrefs	java_awt_event_TextEvent;
};

// Object instance structure
struct _jc_java_awt_event_TextEvent$object {
	_jc_java_awt_event_TextEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_TextEvent$vtype	*vtype;
	_jc_java_awt_event_TextEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_TextEvent$vtype _jc_java_awt_event_TextEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_TextEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_TextEvent$class_object;

#endif	/* _JC_java_awt_event_TextEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/TextEvent.h <==
// public class java.awt.event.TextEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class 724e5862254ff405 java_awt_event_TextEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_TextEvent_H_
#define _JC_java_awt_event_TextEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_TextEvent$sub_refs	_jc_java_awt_event_TextEvent$sub_refs;
typedef struct _jc_java_awt_event_TextEvent$sub_nonrefs	_jc_java_awt_event_TextEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_TextEvent$refs	_jc_java_awt_event_TextEvent$refs;
typedef struct _jc_java_awt_event_TextEvent$nonrefs	_jc_java_awt_event_TextEvent$nonrefs;
typedef struct _jc_java_awt_event_TextEvent$object	_jc_java_awt_event_TextEvent$object;

typedef struct _jc_java_awt_event_TextEvent$fields_struct	_jc_java_awt_event_TextEvent$fields_struct;
typedef const struct _jc_java_awt_event_TextEvent$vmethods	_jc_java_awt_event_TextEvent$vmethods;
typedef const struct _jc_java_awt_event_TextEvent$vtable	_jc_java_awt_event_TextEvent$vtable;
typedef const struct _jc_java_awt_event_TextEvent$vtype	_jc_java_awt_event_TextEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_TextEvent$fields_struct {
	jlong	serialVersionUID;
	jint	TEXT__5fFIRST;
	jint	TEXT__5fLAST;
	jint	TEXT__5fVALUE__5fCHANGED;
};
extern _jc_java_awt_event_TextEvent$fields_struct _jc_java_awt_event_TextEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_TextEvent$method$_init$a57db7ba48d4b8bc(_jc_env *, struct _jc_java_awt_event_TextEvent$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_awt_event_TextEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_TextEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_TextEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_TextEvent$vmethods {
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_TextEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_TextEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_TextEvent$vmethods	java_awt_event_TextEvent;
};

// Vtype
struct _jc_java_awt_event_TextEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_TextEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_TextEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_TextEvent$refs {
    _jc_java_awt_event_TextEvent$sub_refs	java_awt_event_TextEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_TextEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_TextEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_TextEvent$sub_nonrefs	java_awt_event_TextEvent;
};

// Object instance structure
struct _jc_java_awt_event_TextEvent$object {
	_jc_java_awt_event_TextEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_TextEvent$vtype	*vtype;
	_jc_java_awt_event_TextEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_TextEvent$vtype _jc_java_awt_event_TextEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_TextEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_TextEvent$class_object;

#endif	/* _JC_java_awt_event_TextEvent_H_ */
